Silk
====

Silk is a live profiling and inspection tool for the Django framework.
It primarily consists of:

-  Middleware for intercepting Requests/Responses
-  A wrapper around SQL execution for profiling of database queries
-  A context manager/decorator for profiling blocks of code and
   functions either manually or dynamically.
-  A user interface for inspection and visualisation of the above.

Documentation is available at https://github.com/mtford90/silk.
